@@ -117,9 +117,9 @@ class IDBC:
                                 this_sig.factor = f_factor
                                 this_sig.offset = f_offset
                                 this_sig.length_bit = int(f_length_bit)
-                                this_sig.start_bit = int(f_start_bit) - int(f_length_bit) + 1
+                                this_sig.start_bit = self.get_start_bit(int(f_start_bit))
                                 f_now_msg.signal_list.append(this_sig)
-                        if f_line.startswith("BA_ \"GenSigStartValue\""):  # 得到信号的默认值
+                        if f_line.startswith("BA_ \"GenSigStartValue\""):  # 得到信号的cd默认值
                             f_tokens = f_line.split(' ')
                             f_sig_name = f_tokens[4]
                             f_default_value = f_tokens[5].split(';')[0]
@@ -182,6 +182,12 @@ class IDBC:
                         if f_sig.real_signal_name == f_old_sig_name:
                             f_sig.real_signal_name = f_new_sig_name
 
+    @staticmethod
+    def get_start_bit(inter_start_bit):
+        int_value = inter_start_bit // 8
+        remind_value = (inter_start_bit - int_value * 8) % 8
+        return 7 - remind_value + 8 * int_value
+
     def get_all_signals(self) -> dict[str, list[DBCSignal]]:
         """获取当前DBC中所有signal属性
 
